@@ -12,9 +12,11 @@ def from_load(load):
 			trans_data[field.name] = value
 			
 	trans_data['equipment'] = load.equipment_description
-	trans_data['all_in_cost'] = load.rate
+	trans_data['all_in_cost'] = load.rate # all in cost may change at booking
+	trans_data['target_pay'] = load.rate # target_pay is what the broker listed the load for
 	trans_data['multi_stop'] = load.stops
-	
+	trans_data['team_service'] = load.team_service_required
+
 	if isinstance(load.origin, dict):
 		trans_data['origin_city'] = load.origin['city']
 		trans_data['origin_state'] = load.origin['state']
