@@ -82,6 +82,8 @@ class TransactionSchema(CamelCaseSchema):
 	margin = fields.Integer(allow_none=True)
 	rate_type = fields.String(allow_none=True)
 	provider = fields.String(allow_none=True)
+	target_pay = fields.Integer(allow_none=True)
+	max_buy = fields.Integer(allow_none=True)
 
 	@post_load
 	def classify(self, data, **kwargs):
